@@ -5,6 +5,7 @@ from matplotlib.figure import Figure
 from mpl_format.figures.figure_formatter import FigureFormatter
 from pandas import Series, DataFrame
 
+from probability.distributions.conjugate.priors import UniformPrior
 from probability.distributions.continuous.beta import Beta
 from probability.distributions.discrete import Binomial
 from probability.distributions.discrete.beta_binomial import BetaBinomial
@@ -13,7 +14,7 @@ from probability.distributions.mixins.attributes import AlphaFloatMixin, \
 from probability.distributions.mixins.conjugate import ConjugateMixin, \
     PredictiveMixin
 from probability.supports import SUPPORT_BETA
-from probability.utils import is_binomial
+from probability.utils import is_binary, num_format
 
 
 class BetaBinomialConjugate(
@@ -54,22 +55,26 @@ class BetaBinomialConjugate(
     * https://en.wikipedia.org/wiki/Beta-binomial_distribution
     * https://en.wikipedia.org/wiki/Conjugate_prior
     """
-    def __init__(self, alpha: float, beta: float, n: int, k: int):
+    def __init__(self, n: int, k: int,
+                 alpha: float = UniformPrior.Binomial.alpha,
+                 beta: float = UniformPrior.Binomial.beta):
         """
         Create a new beta-binomial distribution.
 
+        :param n: Observed number of trials.
+        :param k: Observed number of successes.
         :param alpha: Value for the α hyper-parameter of the prior Beta
                       distribution.
         :param beta: Value for the β hyper-parameter of the prior Beta
                       distribution.
-        :param n: Observed number of trials.
-        :param k: Observed number of successes.
         """
         self._alpha: float = alpha
         self._beta: float = beta
         self._n: int = n
         self._k: int = k
 
+    # region posterior hyper-parameters
+
     @property
     def alpha_prime(self) -> float:
         return self._alpha + self._k
@@ -78,10 +83,14 @@ class BetaBinomialConjugate(
     def beta_prime(self) -> float:
         return self._beta + self._n - self._k
 
+    # endregion
+
     def prior(self) -> Beta:
         return Beta(
             alpha=self._alpha, beta=self._beta
-        ).with_y_label('$P(p=x|α,β)$').prepend_to_label('Prior: ')
+        ).with_y_label(
+            '$P(α_{Bin}=x|α_{Beta},β_{Beta})$'
+        ).prepend_to_label('Prior: ')
 
     def likelihood(self) -> Binomial:
         return Binomial(
@@ -93,7 +102,13 @@ class BetaBinomialConjugate(
         return Beta(
             alpha=self.alpha_prime,
             beta=self.beta_prime
-        ).with_y_label('$P(p=x|α+k,β+n-k)$').prepend_to_label('Posterior: ')
+        ).with_y_label(
+            '$P(α_{Bin}=x|'
+            'α_{Beta}+k_{Obs},'
+            'β_{Beta}+n_{Obs}-k_{Obs})$'
+        ).prepend_to_label('Posterior: ')
+
+    # region predictive
 
     def prior_predictive(self, n_: Optional[int] = None) -> BetaBinomial:
         """
@@ -109,23 +124,33 @@ class BetaBinomialConjugate(
             n=n_,
             alpha=self._alpha,
             beta=self._beta
-        ).with_y_label(r'$P(\tilde{X}=k|\tilde{n},α,β)$')
+        ).with_y_label(
+            r'$P(\tilde{X}=k|'
+            r'\tilde{n},'
+            r'α_{Beta},'
+            r'β_{Beta})$'
+        )
 
-    def posterior_predictive(self, n_: Optional[int] = None) -> BetaBinomial:
+    def posterior_predictive(self, n_: int) -> BetaBinomial:
         """
         Return a BetaBinomial describing the expected distribution of future
         successes of n trials based on the posterior parameter estimates.
 
-        :param n_: Optional number of trials over which to calculate probability
-                  of success. Leave blank to use the same n as the observed
-                  number of trials.
+        :param n_: Number of trials over which to calculate probability
+                  of success.
         """
-        n_ = n_ if n_ is not None else self._n
         return BetaBinomial(
             n=n_,
             alpha=self.alpha_prime,
             beta=self.beta_prime
-        ).with_y_label(r'$P(\tilde{X}=k|\tilde{n},α+k,β+n-k)$')
+        ).with_y_label(
+            r'$P(\tilde{X}=k|'
+            r'\tilde{n},'
+            r'α_{Beta}+k_{Obs},'
+            r'β_{Beta}+n_{Obs}-k_{Obs})$'
+        )
+
+    # endregion
 
     def plot(self, n_, **kwargs) -> Figure:
         """
@@ -173,30 +198,39 @@ class BetaBinomialConjugate(
         return ff.figure
 
     @staticmethod
-    def infer_posterior(data: Series) -> Beta:
+    def infer_posterior(data: Series,
+                        alpha: float = UniformPrior.Binomial.alpha,
+                        beta: float = UniformPrior.Binomial.beta) -> Beta:
         """
         Return a new Beta distribution of the posterior most likely to generate
         the given data.
 
         :param data: Series of `1`s and `0`s or `True`s and `False`s
+        :param alpha: Value for the α hyper-parameter of the prior Beta
+                      distribution.
+        :param beta: Value for the β hyper-parameter of the prior Beta
+                     distribution.
         """
-        alpha: int = data.sum()
-        beta: int = len(data) - alpha
-        return Beta(alpha=alpha, beta=beta)
+        return BetaBinomialConjugate(
+            alpha=alpha, beta=beta,
+            n=len(data), k=data.sum()
+        ).posterior()
 
     @staticmethod
     def infer_posteriors(
             data: DataFrame,
             prob_vars: Union[str, List[str]],
             cond_vars: Union[str, List[str]],
-            stats: Optional[Union[str, dict, List[Union[str, dict]]]] = None
+            stats: Optional[Union[str, dict, List[Union[str, dict]]]] = None,
+            alpha: float = UniformPrior.Binomial.alpha,
+            beta: float = UniformPrior.Binomial.beta
     ) -> DataFrame:
         """
         Return a DataFrame mapping probability and conditional variables to Beta
         distributions of posteriors most likely to generate the given data.
 
         :param data: DataFrame containing discrete data.
-        :param prob_vars: Name(s) of binomial (or name of multinomial) variables
+        :param prob_vars: Name(s) of binary variables
                           whose posteriors to find probability of.
         :param cond_vars: Names of discrete variables to condition on.
                           Calculations will be done for the cartesian product
@@ -206,18 +240,19 @@ class BetaBinomialConjugate(
         :param stats: Optional stats to append to the output e.g. 'alpha',
                       'median'. To pass arguments use a dict mapping stat
                       name to iterable of args.
-        :return: DataFrame with columns for each conditioning variable, a
-                 'prob_var' column indicating the probability variable, a
-                 `prob_val` column indicating the value of the probability
+        :param alpha: Value for the α hyper-parameter of each prior Beta
+                      distribution.
+        :param beta: Value for the β hyper-parameter of each prior Beta
+                     distribution.
+        :return: DataFrame with columns for each conditioning variable,
+                 a 'prob_var' column indicating the probability variable,
+                 a `prob_val` column indicating the value of the probability
                  variable, and a `Beta` column containing the distribution.
         """
         if isinstance(prob_vars, str):
             prob_vars = [prob_vars]
-        if len(prob_vars) > 1:
-            if not all(is_binomial(data[prob_var]) for prob_var in prob_vars):
-                raise ValueError(
-                    'If passing more than one prob_var, each must be binomial'
-                )
+        if not all(is_binary(data[prob_var]) for prob_var in prob_vars):
+            raise ValueError('Prob vars must be binary valued')
         if isinstance(cond_vars, str):
             cond_vars = [cond_vars]
         cond_products = product(
@@ -238,32 +273,20 @@ class BetaBinomialConjugate(
                 cond_dict[cond_var] = cond_value
             n_cond: int = len(cond_data)
             for prob_var in prob_vars:
-                if is_binomial(data[prob_var]):
-                    # one or more binomial columns
-                    prob_dict = cond_dict.copy()
-                    m_prob: int = cond_data[prob_var].sum()
-                    prob_dict['prob_var'] = prob_var
-                    prob_dict['prob_val'] = 1
-                    beta = Beta(alpha=m_prob, beta=n_cond - m_prob)
-                    prob_dict['Beta'] = beta
-                    for stat in stats:
-                        prob_dict = {**prob_dict, ** beta.stat(stat, True)}
-                    betas.append(prob_dict)
-                else:
-                    # single multinomial column
-                    for state in data[prob_var].unique():
-                        prob_dict = cond_dict.copy()
-                        m_prob = len(cond_data.loc[
-                            cond_data[prob_var] == state,
-                            prob_var
-                        ])
-                        prob_dict['prob_var'] = prob_var
-                        prob_dict['prob_val'] = state
-                        beta = Beta(alpha=m_prob, beta=n_cond - m_prob)
-                        prob_dict['Beta'] = beta
-                        for stat in stats:
-                            prob_dict = {**prob_dict, **beta.stat(stat, True)}
-                        betas.append(prob_dict)
+                # one or more binomial columns
+                prob_dict = cond_dict.copy()
+                m_prob: int = cond_data[prob_var].sum()
+                prob_dict['prob_var'] = prob_var
+                prob_dict['prob_val'] = 1
+                posterior = BetaBinomialConjugate(
+                    alpha=alpha, beta=beta,
+                    n=n_cond, k=m_prob
+                ).posterior()
+                prob_dict['Beta'] = posterior
+                for stat in stats:
+                    prob_dict = {**prob_dict,
+                                 ** posterior.stat(stat, True)}
+                betas.append(prob_dict)
 
         betas_data = DataFrame(betas)
 
@@ -273,8 +296,8 @@ class BetaBinomialConjugate(
 
         return (
             f'BetaBinomial('
-            f'α={self._alpha}, '
-            f'β={self._beta}, '
+            f'α={num_format(self._alpha, 3)}, '
+            f'β={num_format(self._beta, 3)}, '
             f'n={self._n}, k={self._k})'
         )
 
