@@ -6,8 +6,9 @@ from scipy.stats import norm, rv_continuous
 from probability.distributions.mixins.attributes import MuFloatDMixin, \
     SigmaFloatDMixin
 from probability.distributions.mixins.calculable_mixins import CalculableMixin
-from probability.distributions.mixins.rv_continuous_1d_mixin import RVContinuous1dMixin
-from probability.utils import any_are_not_none, any_are_none
+from probability.distributions.mixins.rv_continuous_1d_mixin import \
+    RVContinuous1dMixin
+from probability.utils import any_are_not_none, any_are_none, num_format
 
 
 class Normal(
@@ -66,9 +67,17 @@ class Normal(
     def __str__(self):
 
         if self._parameterization == 'μσ':
-            return f'Normal(μ={self._mu}, σ={self._sigma})'
+            return (
+                f'Normal('
+                f'μ={num_format(self._mu, 3)}, '
+                f'σ={num_format(self._sigma, 3)})'
+            )
         elif self._parameterization == 'μσ²':
-            return f'Normal(μ={self._mu}, σ²={self.sigma_sq})'
+            return (
+                f'Normal('
+                f'μ={num_format(self._mu, 3)}, '
+                f'σ²={num_format(self.sigma_sq, 3)})'
+            )
 
     def __repr__(self):
 
