@@ -2,7 +2,9 @@ from scipy.stats import geom, rv_discrete
 
 from probability.distributions.mixins.attributes import PFloatDMixin
 from probability.distributions.mixins.calculable_mixins import CalculableMixin
-from probability.distributions.mixins.rv_discrete_1d_mixin import RVDiscrete1dMixin
+from probability.distributions.mixins.rv_discrete_1d_mixin import \
+    RVDiscrete1dMixin
+from probability.utils import num_format
 
 
 class Geometric(
@@ -33,7 +35,7 @@ class Geometric(
 
     def __str__(self):
 
-        return f'Geometric(p={self._p})'
+        return f'Geometric(p={num_format(self._p, 3)})'
 
     def __repr__(self):
 
