@@ -2,7 +2,9 @@ from scipy.stats import rv_discrete, nbinom
 
 from probability.distributions.mixins.attributes import PFloatDMixin
 from probability.distributions.mixins.calculable_mixins import CalculableMixin
-from probability.distributions.mixins.rv_discrete_1d_mixin import RVDiscrete1dMixin
+from probability.distributions.mixins.rv_discrete_1d_mixin import \
+    RVDiscrete1dMixin
+from probability.utils import num_format
 
 
 class NegativeBinomial(
@@ -54,7 +56,11 @@ class NegativeBinomial(
 
     def __str__(self):
 
-        return f'NegativeBinomial(r={self._r}, p={self._p})'
+        return (
+            f'NegativeBinomial('
+            f'r={num_format(self._r, 3)}, '
+            f'p={num_format(self._p, 3)})'
+        )
 
     def __repr__(self):
 
