@@ -1,8 +1,9 @@
+from typing import Tuple, Optional, Union, Iterable, List
+
 from numpy import ndarray
-from pandas import DataFrame, Series, MultiIndex
+from pandas import DataFrame, Series
 from scipy.stats import rv_continuous, rv_discrete
 from scipy.stats._distn_infrastructure import rv_generic
-from typing import Tuple, Optional, Union, Iterable, List
 
 from probability.distributions.functions.continuous_function_1d import \
     ContinuousFunction1d
@@ -42,24 +43,57 @@ class RVS1dMixin(object):
 
         return (self.rvs(num_samples) < other.rvs(num_samples)).mean()
 
-    def __gt__(self, other: 'RVS1dMixin') -> float:
+    def __gt__(self, other: Union['RVS1dMixin', float]) -> float:
 
-        return (
-            self.rvs(NUM_SAMPLES_COMPARISON) >
-            other.rvs(NUM_SAMPLES_COMPARISON)
-        ).mean()
+        if isinstance(other, float):
+            return (self.rvs(NUM_SAMPLES_COMPARISON) > other).mean()
+        elif isinstance(other, RVS1dMixin):
+            return (
+                self.rvs(NUM_SAMPLES_COMPARISON) >
+                other.rvs(NUM_SAMPLES_COMPARISON)
+            ).mean()
+        else:
+            raise TypeError('other must be of type float or Rvs1dMixin')
 
-    def __lt__(self, other: 'RVS1dMixin') -> float:
+    def __ge__(self, other: Union['RVS1dMixin', float]) -> float:
 
-        return (
-            self.rvs(NUM_SAMPLES_COMPARISON) <
-            other.rvs(NUM_SAMPLES_COMPARISON)
-        ).mean()
+        if isinstance(other, float):
+            return (self.rvs(NUM_SAMPLES_COMPARISON) >= other).mean()
+        elif isinstance(other, RVS1dMixin):
+            return (
+                self.rvs(NUM_SAMPLES_COMPARISON) >=
+                other.rvs(NUM_SAMPLES_COMPARISON)
+            ).mean()
+        else:
+            raise TypeError('other must be of type float or Rvs1dMixin')
+
+    def __lt__(self, other: Union['RVS1dMixin', float]) -> float:
+
+        if isinstance(other, float):
+            return (self.rvs(NUM_SAMPLES_COMPARISON) < other).mean()
+        elif isinstance(other, RVS1dMixin):
+            return (
+                self.rvs(NUM_SAMPLES_COMPARISON) <
+                other.rvs(NUM_SAMPLES_COMPARISON)
+            ).mean()
+        else:
+            raise TypeError('other must be of type float or Rvs1dMixin')
+
+    def __le__(self, other: Union['RVS1dMixin', float]) -> float:
+
+        if isinstance(other, float):
+            return (self.rvs(NUM_SAMPLES_COMPARISON) <= other).mean()
+        elif isinstance(other, RVS1dMixin):
+            return (
+                self.rvs(NUM_SAMPLES_COMPARISON) <=
+                other.rvs(NUM_SAMPLES_COMPARISON)
+            ).mean()
+        else:
+            raise TypeError('other must be of type float or Rvs1dMixin')
 
 
 class RVSNdMixin(object):
 
-    _distribution: rv_generic
     _names: List[str]
 
     def rvs(self, num_samples: int,
@@ -228,14 +262,13 @@ class PDF1dMixin(object):
         """
         return ContinuousFunction1d(
             distribution=self._distribution,
-            method_name='logpdf', name='log(PDF)',
+            method_name='logpdf', name='log PDF',
             parent=self
         )
 
 
 class PDFNdMixin(object):
 
-    _distribution: rv_generic
     _num_dims: int
 
     def pdf(self) -> ContinuousFunctionNd:
@@ -255,7 +288,7 @@ class PDFNdMixin(object):
         """
         return ContinuousFunctionNd(
             distribution=self._distribution,
-            method_name='logpdf', name='log(PDF)',
+            method_name='logpdf', name='log PDF',
             num_dims=self._num_dims,
             parent=self
         )
@@ -281,14 +314,13 @@ class PMF1dMixin(object):
         """
         return DiscreteFunction1d(
             distribution=self._distribution,
-            method_name='logpmf', name='log(PMF)',
+            method_name='logpmf', name='log PMF',
             parent=self
         )
 
 
 class PMFNdMixin(object):
 
-    _distribution: rv_generic
     _num_dims: int
 
     def pmf(self) -> DiscreteFunctionNd:
@@ -308,7 +340,7 @@ class PMFNdMixin(object):
         """
         return DiscreteFunctionNd(
             distribution=self._distribution,
-            method_name='logpmf', name='log(PMF)',
+            method_name='logpmf', name='log PMF',
             num_dims=self._num_dims,
             parent=self
         )
@@ -334,14 +366,13 @@ class CDFContinuous1dMixin(object):
         """
         return ContinuousFunction1d(
             distribution=self._distribution,
-            method_name='logcdf', name='log(CDF)',
+            method_name='logcdf', name='log CDF',
             parent=self
         )
 
 
 class CDFContinuousNdMixin(object):
 
-    _distribution: rv_continuous
     _num_dims: int
 
     def cdf(self) -> ContinuousFunctionNd:
@@ -361,7 +392,7 @@ class CDFContinuousNdMixin(object):
         """
         return ContinuousFunctionNd(
             distribution=self._distribution,
-            method_name='logcdf', name='log(CDF)',
+            method_name='logcdf', name='log CDF',
             num_dims=self._num_dims,
             parent=self
         )
@@ -387,7 +418,7 @@ class CDFDiscrete1dMixin(object):
         """
         return DiscreteFunction1d(
             distribution=self._distribution,
-            method_name='logcdf', name='log(CDF)',
+            method_name='logcdf', name='log CDF',
             parent=self
         )
 
@@ -412,7 +443,7 @@ class SFContinuous1dMixin(object):
         """
         return ContinuousFunction1d(
             distribution=self._distribution,
-            method_name='sf', name='log(SF)',
+            method_name='sf', name='log SF',
             parent=self
         )
 
@@ -437,7 +468,7 @@ class SFDiscrete1dMixin(object):
         """
         return DiscreteFunction1d(
             distribution=self._distribution,
-            method_name='logsf', name='log(SF)',
+            method_name='logsf', name='log SF',
             parent=self
         )
 
