@@ -36,8 +36,16 @@ def any_are_none(*args) -> bool:
     return any([arg is None for arg in args])
 
 
-def is_binomial(data: Series) -> bool:
+def is_binary(data: Series) -> bool:
 
     return (
         set(data.unique()).issubset({0, 1})
     )
+
+
+def num_format(number: float, max_dp: int) -> str:
+
+    for ndp in range(max_dp):
+        if round(number, ndp) == number:
+            return f'{number:0.{ndp}f}'
+    return f'{number:0.{max_dp}f}'
